@@ -153,7 +153,7 @@ restore_default_location (GeditFileBrowserPlugin * plugin,
 	if (root != NULL && *root != '\0') {
 		uri = gnome_vfs_uri_new (root);
 
-		if (uri == NULL || (!remote && !gnome_vfs_uri_is_local (uri))) {
+		if (uri == NULL || (!remote && !gedit_file_browser_utils_is_local (root))) {
 		} else if (virtual != NULL && virtual != '\0') {
 			gedit_file_browser_widget_set_root_and_virtual_root (data->tree_widget, 
 			                                                     root,
@@ -213,15 +213,17 @@ restore_filter (GeditFileBrowserPluginData * data)
 	gedit_file_browser_store_set_filter_mode (
 	    gedit_file_browser_widget_get_browser_store (data->tree_widget),
 	    mode);
-	    
-	
+
 	pattern = gconf_client_get_string (client,
 	                                   FILE_BROWSER_BASE_KEY "/filter_pattern",
 	                                   NULL);
 
 	gedit_file_browser_widget_set_filter_pattern (data->tree_widget, 
 	                                              pattern);
+
 	g_object_unref (client);
+	g_free (filter_mode);
+	g_free (pattern);
 }
 
 static void
@@ -231,7 +233,8 @@ set_root_from_doc (GeditFileBrowserPluginData * data,
 	gchar * uri;
 	gchar * root;
 	GnomeVFSURI * guri;
-	
+	GnomeVFSURI * parent;
+
 	if (doc == NULL)
 		return;
 	
@@ -242,11 +245,16 @@ set_root_from_doc (GeditFileBrowserPluginData * data,
 	
 	guri = gnome_vfs_uri_new (uri);
 	
-	if (guri == NULL)
+	if (guri == NULL) {
+		g_free (uri);
 		return;
+	}
 	
-	if (gnome_vfs_uri_has_parent(guri))
-		guri = gnome_vfs_uri_get_parent (guri);
+	if (gnome_vfs_uri_has_parent(guri)) {
+		parent = gnome_vfs_uri_get_parent (guri);
+		gnome_vfs_uri_unref (guri);
+		guri = parent;
+	}
 
 	root = gnome_vfs_uri_to_string (guri, GNOME_VFS_URI_HIDE_NONE);
 
@@ -738,7 +746,7 @@ on_virtual_root_changed_cb (GeditFileBrowserStore * store,
 		gtk_action_set_sensitive (
 			gtk_action_group_get_action (data->action_group, 
 	                                            "OpenTerminal"),
-	                guri != NULL && gnome_vfs_uri_is_local (guri));
+	                guri != NULL && gedit_file_browser_utils_is_local (virtual));
 		
 		if (guri != NULL)
 			gnome_vfs_uri_unref (guri);
